@@ -1,4 +1,4 @@
-use bgp_models::prelude::*;
+use bgpkit_parser::models::*;
 use bgpkit_parser::BgpkitParser;
 
 /// an very simple example that reads a remote BGP data file and print out the message count.
