@@ -1,6 +1,7 @@
+use crate::models::*;
 use crate::parser::bgp::messages::parse_bgp_message;
 use crate::parser::bmp::error::ParserBmpError;
-use bgp_models::prelude::*;
+use bytes::Bytes;
 
 #[derive(Debug)]
 pub struct RouteMonitoring {
@@ -8,7 +9,7 @@ pub struct RouteMonitoring {
 }
 
 pub fn parse_route_monitoring(
-    data: &[u8],
+    data: &mut Bytes,
     asn_len: &AsnLength,
 ) -> Result<RouteMonitoring, ParserBmpError> {
     // let bgp_update = parse_bgp_update_message(reader, false, afi, asn_len, total_len)?;
